import json

from inventory_provider.routes import common

from flask import Blueprint, Response


routes = Blueprint("inventory-data-inf-classifier-support-routes", __name__)


@routes.errorhandler(500)
def handle_500_error(error):
    return Response(
       response=str(error),
       status=500)


@routes.errorhandler(422)
def handle_422_error(error):
    return Response(
       response=str(error),
       status=422)


@routes.route("/trap-metadata/<source_equipment>/<path:interface>",
              methods=['GET', 'POST'])
@common.require_accepts_json
def get_trap_metadata(source_equipment, interface):
    r = common.get_redis()

    cache_key = 'classifier:infinera:cache:%s:%s' % (source_equipment,
                                                     interface)
    result = r.get(cache_key)

    if result:
        result = result.decode('utf-8')
    else:
        result = {}

        services = r.get(
            'opsdb:interface_services:%s:%s' % (source_equipment, interface))
        if services:
            result['services'] = json.loads(services.decode('utf=8'))
            geant_lambdas = []
            for s in result['services']:
                gl = r.get('opsdb:geant_lambdas:%s' % s['name'])
                if gl:
                    t_gl = json.loads(gl.decode('utf=8'))
                    t_gl['status'] = t_gl['status'].lower()
                    geant_lambdas.append(t_gl)

            if geant_lambdas:
                result['geant-lambdas'] = geant_lambdas

        if not result:
            return Response(
                response="no available info for {} {}".format(
                    source_equipment, interface),
                status=404,
                mimetype="text/html")

        result = json.dumps(result)
        # cache this data for the next call
        r.set(cache_key, result.encode('utf-8'))

    return Response(result, mimetype="application/json")
